pub struct VmmProcess { /* private fields */ }Expand description
Stable identity for a VM monitor process.
Implementations
Sourceimpl VmmProcess
impl VmmProcess
pub fn pid(&self) -> u32
pub fn start_time_ticks(&self) -> Option<u64>
Sourcepub fn new(pid: u32, start_time_ticks: Option<u64>) -> Self
pub fn new(pid: u32, start_time_ticks: Option<u64>) -> Self
Create a stable VM monitor process identity.
start_time_ticks should come from the process start-time field in
/proc/<pid>/stat when available so the identity can detect PID reuse.
Pass None only when the platform cannot provide that information.